@@ -1,11 +1,12 @@
 /*
-    $Id: mmc.h,v 1.24 2006/02/16 20:09:27 rocky Exp $
+    $Id: mmc.h,v 1.32 2008/05/09 06:13:32 edsdead Exp $
 
-    Copyright (C) 2003, 2004, 2005, 2006 Rocky Bernstein <rocky@panix.com>
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008
+                  Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -14,11 +15,10 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/*!
+/**
  *  \file mmc.h 
  * 
  *  \brief Common definitions for MMC (Multimedia Commands). Applications
@@ -37,22 +37,22 @@
 extern "C" {
 #endif /* __cplusplus */
 
-  /*! Set this to the maximum value in milliseconds that we will
+  /** Set this to the maximum value in milliseconds that we will
       wait on an MMC command.  */
   extern uint32_t mmc_timeout_ms; 
 
-  /*! The default timeout (non-read) is 6 seconds. */
+  /** The default timeout (non-read) is 6 seconds. */
 #define MMC_TIMEOUT_DEFAULT 6000
 
-  /*! Set this to the maximum value in milliseconds that we will
+  /** Set this to the maximum value in milliseconds that we will
       wait on an MMC read command.  */
   extern uint32_t mmc_read_timeout_ms;
 
-  /*! The default read timeout is 3 minutes. */
+  /** The default read timeout is 3 minutes. */
 #define MMC_READ_TIMEOUT_DEFAULT 3*60*1000
 
 
-  /*! \brief The opcode-portion (generic packet commands) of an MMC command.
+  /** \brief The opcode-portion (generic packet commands) of an MMC command.
     
   In general, those opcodes that end in 6 take a 6-byte command
   descriptor, those that end in 10 take a 10-byte
@@ -175,32 +175,39 @@ extern "C" {
                                               return */
   } cdio_mmc_read_sub_state_t;
 
-/*! Level values that can go into READ_CD */
-#define CDIO_MMC_READ_TYPE_ANY   0  /**< All types */
-#define CDIO_MMC_READ_TYPE_CDDA  1  /**< Only CD-DA sectors */
-#define CDIO_MMC_READ_TYPE_MODE1 2  /**< mode1 sectors (user data = 2048) */
-#define CDIO_MMC_READ_TYPE_MODE2 3  /**< mode2 sectors form1 or form2 */
-#define CDIO_MMC_READ_TYPE_M2F1  4  /**< mode2 sectors form1 */
-#define CDIO_MMC_READ_TYPE_M2F2  5  /**< mode2 sectors form2 */
+  /** Level values that can go into READ_CD */
+  typedef enum {
+    CDIO_MMC_READ_TYPE_ANY  =  0,  /**< All types */
+    CDIO_MMC_READ_TYPE_CDDA =  1,  /**< Only CD-DA sectors */
+    CDIO_MMC_READ_TYPE_MODE1 = 2,  /**< mode1 sectors (user data = 2048) */
+    CDIO_MMC_READ_TYPE_MODE2 = 3,  /**< mode2 sectors form1 or form2 */
+    CDIO_MMC_READ_TYPE_M2F1 =  4,  /**< mode2 sectors form1 */
+    CDIO_MMC_READ_TYPE_M2F2 =  5   /**< mode2 sectors form2 */
+  } cdio_mmc_read_cd_type_t;
 
-/*! Format values for READ_TOC */
-#define CDIO_MMC_READTOC_FMT_TOC      0
-#define CDIO_MMC_READTOC_FMT_SESSION  1  
-#define CDIO_MMC_READTOC_FMT_FULTOC   2  
-#define CDIO_MMC_READTOC_FMT_PMA      3  /**< Q subcode data */
-#define CDIO_MMC_READTOC_FMT_ATIP     4  /**< includes media type */
-#define CDIO_MMC_READTOC_FMT_CDTEXT   5  /**< CD-TEXT info  */
-
-/*! Page codes for MODE SENSE and MODE SET. */
-#define CDIO_MMC_R_W_ERROR_PAGE		0x01
-#define CDIO_MMC_WRITE_PARMS_PAGE	0x05
-#define CDIO_MMC_CDR_PARMS_PAGE		0x0d
-#define CDIO_MMC_AUDIO_CTL_PAGE		0x0e
-#define CDIO_MMC_POWER_PAGE		0x1a
-#define CDIO_MMC_FAULT_FAIL_PAGE	0x1c
-#define CDIO_MMC_TO_PROTECT_PAGE	0x1d
-#define CDIO_MMC_CAPABILITIES_PAGE	0x2a
-#define CDIO_MMC_ALL_PAGES		0x3f
+  /** Format values for READ_TOC */
+  typedef enum {
+    CDIO_MMC_READTOC_FMT_TOC     =  0,
+    CDIO_MMC_READTOC_FMT_SESSION =  1,  
+    CDIO_MMC_READTOC_FMT_FULTOC  =  2,
+    CDIO_MMC_READTOC_FMT_PMA     =  3,  /**< Q subcode data */
+    CDIO_MMC_READTOC_FMT_ATIP    =  4,  /**< includes media type */
+    CDIO_MMC_READTOC_FMT_CDTEXT  =  5   /**< CD-TEXT info  */
+  } cdio_mmc_readtoc_t;
+    
+/** Page codes for MODE SENSE and MODE SET. */
+  typedef enum {
+    CDIO_MMC_R_W_ERROR_PAGE	= 0x01,
+    CDIO_MMC_WRITE_PARMS_PAGE	= 0x05,
+    CDIO_MMC_CDR_PARMS_PAGE	= 0x0d,
+    CDIO_MMC_AUDIO_CTL_PAGE	= 0x0e,
+    CDIO_MMC_POWER_PAGE		= 0x1a,
+    CDIO_MMC_FAULT_FAIL_PAGE	= 0x1c,
+    CDIO_MMC_TO_PROTECT_PAGE	= 0x1d,
+    CDIO_MMC_CAPABILITIES_PAGE	= 0x2a,
+    CDIO_MMC_ALL_PAGES		= 0x3f,
+  } cdio_mmc_mode_page_t;
+    
 
 PRAGMA_BEGIN_PACKED
   struct mmc_audio_volume_entry_s 
@@ -211,7 +218,7 @@ PRAGMA_BEGIN_PACKED
 
   typedef struct mmc_audio_volume_entry_s mmc_audio_volume_entry_t;
   
-  /*! This struct is used by cdio_audio_get_volume and cdio_audio_set_volume */
+  /** This struct is used by cdio_audio_get_volume and cdio_audio_set_volume */
   struct mmc_audio_volume_s
   {
     mmc_audio_volume_entry_t port[4];
@@ -222,7 +229,7 @@ PRAGMA_BEGIN_PACKED
 PRAGMA_END_PACKED
   
 
-/*! Return type codes for GET_CONFIGURATION. */
+/** Return type codes for GET_CONFIGURATION. */
 typedef enum {
   CDIO_MMC_GET_CONF_ALL_FEATURES     = 0,  /**< all features without regard
                                               to currency. */
@@ -234,7 +241,7 @@ typedef enum {
 } cdio_mmc_get_conf_t;
   
 
-/*! FEATURE codes used in GET CONFIGURATION. */
+/** FEATURE codes used in GET CONFIGURATION. */
 
 typedef enum {
   CDIO_MMC_FEATURE_PROFILE_LIST     = 0x000, /**< Profile List Feature */
@@ -295,7 +302,7 @@ typedef enum {
 						report */
 } cdio_mmc_feature_t;
 				
-/*! Profile profile codes used in GET_CONFIGURATION - PROFILE LIST. */
+/** Profile profile codes used in GET_CONFIGURATION - PROFILE LIST. */
 typedef enum {
   CDIO_MMC_FEATURE_PROF_NON_REMOVABLE = 0x0001, /**< Re-writable disk, capable
 						   of changing behavior */
@@ -343,19 +350,19 @@ typedef enum {
 } cdio_mmc_feature_interface_t;
   
 
-/*! The largest Command Descriptor Block (CDB) size.
+/** The largest Command Descriptor Block (CDB) size.
     The possible sizes are 6, 10, and 12 bytes.
  */
 #define MAX_CDB_LEN 12
 
-/*! \brief A Command Descriptor Block (CDB) used in sending MMC 
+/** \brief A Command Descriptor Block (CDB) used in sending MMC 
     commands.
  */
 typedef struct mmc_cdb_s {
   uint8_t field[MAX_CDB_LEN];
 } mmc_cdb_t;
   
-  /*! \brief Format of header block in data returned from an MMC
+  /** \brief Format of header block in data returned from an MMC
     GET_CONFIGURATION command.
   */
   typedef struct mmc_feature_list_header_s {
@@ -369,7 +376,7 @@ typedef struct mmc_cdb_s {
     unsigned char profile_lsb;
   } cdio_mmc_feature_list_header_t;
 
-  /*! An enumeration indicating whether an MMC command is sending
+  /** An enumeration indicating whether an MMC command is sending
     data or getting data.
   */
   typedef enum mmc_direction_s {
@@ -391,23 +398,26 @@ typedef struct mmc_cdb_s {
     uint8_t       rel_addr[4];
   } cdio_mmc_subchannel_t;
   
-#define CDIO_MMC_SET_COMMAND(cdb, command) \
+#define CDIO_MMC_SET_COMMAND(cdb, command)      \
   cdb[0] = command
   
 #define CDIO_MMC_SET_READ_TYPE(cdb, sector_type) \
   cdb[1] = (sector_type << 2)
   
-#define CDIO_MMC_GET_LEN16(p) \
+#define CDIO_MMC_GETPOS_LEN16(p, pos)           \
+  (p[pos]<<8) + p[pos+1]
+  
+#define CDIO_MMC_GET_LEN16(p)                   \
   (p[0]<<8) + p[1]
   
 #define CDIO_MMC_GET_LEN32(p) \
   (p[0] << 24) + (p[1] << 16) + (p[2] << 8) + p[3];
   
-#define CDIO_MMC_SET_LEN16(cdb, pos, len)  \
-  cdb[pos  ] = (len >>  8) & 0xff; \
+#define CDIO_MMC_SET_LEN16(cdb, pos, len)       \
+  cdb[pos  ] = (len >>  8) & 0xff;              \
   cdb[pos+1] = (len      ) & 0xff
 
-#define CDIO_MMC_SET_READ_LBA(cdb, lba) \
+#define CDIO_MMC_SET_READ_LBA(cdb, lba)         \
   cdb[2] = (lba >> 24) & 0xff; \
   cdb[3] = (lba >> 16) & 0xff; \
   cdb[4] = (lba >>  8) & 0xff; \
@@ -432,7 +442,7 @@ typedef struct mmc_cdb_s {
 #define CDIO_MMC_SET_MAIN_CHANNEL_SELECTION_BITS(cdb, val) \
   cdb[9] = val << 3;
 
-/*!
+/**
   Read Audio Subchannel information
   
   @param p_cdio the CD object to be acted upon.
@@ -442,58 +452,55 @@ driver_return_code_t
 mmc_audio_read_subchannel (CdIo_t *p_cdio, 
                            /*out*/ cdio_subchannel_t *p_subchannel);
   
-  /*!
+  /**
     Return a string containing the name of the audio state as returned from
     the Q_SUBCHANNEL.
   */
   const char *mmc_audio_state2str( uint8_t i_audio_state );
   
-  /*!
+  /**
     Eject using MMC commands. If CD-ROM is "locked" we'll unlock it.
     Command is not "immediate" -- we'll wait for the command to complete.
     For a more general (and lower-level) routine, @see mmc_start_stop_media.
   */
   driver_return_code_t mmc_eject_media( const CdIo_t *p_cdio );
   
-  /*!
+  /**
     Return a string containing the name of the given feature
   */
   const char *mmc_feature2str( int i_feature );
   
-  /*!
+  /**
     Return a string containing the name of the given feature
   */
   const char *mmc_feature_profile2str( int i_feature_profile );
   
-  /*!  
+  /**  
     Return the length in bytes of the Command Descriptor
     Buffer (CDB) for a given MMC command. The length will be 
     either 6, 10, or 12. 
   */
   uint8_t mmc_get_cmd_len(uint8_t mmc_cmd);
   
-  /*!
+  /**
     Get the block size used in read requests, via MMC.
     @return the blocksize if > 0; error if <= 0
   */
   int mmc_get_blocksize ( CdIo_t *p_cdio );
   
-#if 0
-  /*! Don't know how to implement yet. */
-  /*!
+  /**
    * Close tray using a MMC START STOP command.
    */
-  driver_return_code_t mmc_close_tray( const char *psz_device );
-#endif
+  driver_return_code_t mmc_close_tray( CdIo_t *p_cdio );
   
-  /*!  
+  /**  
     Get the lsn of the end of the CD
     
     @return the lsn. On error return CDIO_INVALID_LSN.
   */
   lsn_t mmc_get_disc_last_lsn( const CdIo_t *p_cdio );
   
-  /*! 
+  /** 
     Return the discmode as reported by the MMC Read (FULL) TOC
     command.
     
@@ -505,7 +512,7 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
   discmode_t mmc_get_discmode( const CdIo_t *p_cdio );
   
   
-  /*!
+  /**
     Get drive capabilities for a device.
     @return the drive capabilities.
   */
@@ -522,13 +529,13 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
     CDIO_MMC_LEVEL_NONE
   } cdio_mmc_level_t;
   
-  /*!
+  /**
     Get the MMC level supported by the device.
   */
   cdio_mmc_level_t mmc_get_drive_mmc_cap(CdIo_t *p_cdio);
   
 
-  /*! 
+  /** 
     Get the DVD type associated with cd object.
     
     @return the DVD discmode.
@@ -537,6 +544,23 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
                                            cdio_dvd_struct_t *s);
   
   /*! 
+    Return results of media status
+    @param p_cdio the CD object to be acted upon.
+    @param out_buf media status code from operation
+    @return DRIVER_OP_SUCCESS (0) if we got the status.
+    return codes are the same as driver_return_code_t
+   */
+  int mmc_get_event_status(const CdIo_t *p_cdio, uint8_t out_buf[2]);
+
+  /*! 
+    Find out if media tray is open or closed.
+    @param p_cdio the CD object to be acted upon.
+    @return 1 if media is open, 0 if closed. Error
+    return codes are the same as driver_return_code_t
+  */
+  int mmc_get_tray_status ( const CdIo_t *p_cdio );
+
+  /** 
     Get the CD-ROM hardware info via an MMC INQUIRY command.
     
     @return true if we were able to get hardware info, false if we had
@@ -546,7 +570,7 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
                         /* out*/ cdio_hwinfo_t *p_hw_info );
   
   
-  /*! 
+  /** 
     Find out if media has changed since the last call.
     @param p_cdio the CD object to be acted upon.
     @return 1 if media has changed since last call, 0 if not. Error
@@ -554,7 +578,7 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
   */
   int mmc_get_media_changed(const CdIo_t *p_cdio);
   
-  /*!
+  /**
     Get the media catalog number (MCN) from the CD via MMC.
     
     @return the media catalog number r NULL if there is none or we
@@ -573,7 +597,7 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
   driver_return_code_t mmc_audio_get_volume (CdIo_t *p_cdio,  /*out*/
                                              mmc_audio_volume_t *p_volume);
   
-  /*!
+  /**
     Report if CD-ROM has a praticular kind of interface (ATAPI, SCSCI, ...)
     Is it possible for an interface to have serveral? If not this 
     routine could probably return the single mmc_feature_interface_t.
@@ -582,7 +606,7 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
   bool_3way_t mmc_have_interface( CdIo_t *p_cdio, 
                                   cdio_mmc_feature_interface_t e_interface );
   
-  /*! Run a MODE_SENSE command (6- or 10-byte version) 
+  /** Run a MODE_SENSE command (6- or 10-byte version) 
     and put the results in p_buf 
     @return DRIVER_OP_SUCCESS if we ran the command ok.
   */
@@ -590,21 +614,21 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
                       int page);
   
   
-  /*! Run a MODE_SENSE command (10-byte version) 
+  /** Run a MODE_SENSE command (10-byte version) 
     and put the results in p_buf 
     @return DRIVER_OP_SUCCESS if we ran the command ok.
   */
   int  mmc_mode_sense_10( CdIo_t *p_cdio, /*out*/ void *p_buf, int i_size, 
                           int page);
   
-  /*! Run a MODE_SENSE command (6-byte version) 
+  /** Run a MODE_SENSE command (6-byte version) 
     and put the results in p_buf 
     @return DRIVER_OP_SUCCESS if we ran the command ok.
   */
   int  mmc_mode_sense_6( CdIo_t *p_cdio, /*out*/ void *p_buf, int i_size, 
                          int page);
   
-  /*! Issue a MMC READ_CD command.
+  /** Issue a MMC READ_CD command.
     
   @param p_cdio  object to read from 
   
@@ -712,7 +736,7 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
                 uint8_t subchannel_selection, uint16_t i_blocksize, 
                 uint32_t i_blocks );
   
-  /*! Read just the user data part of some sort of data sector (via 
+  /** Read just the user data part of some sort of data sector (via 
     mmc_read_cd). 
     
     @param p_cdio object to read from
@@ -735,14 +759,15 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
                                                uint16_t i_blocksize,
                                                uint32_t i_blocks );
   
-  /*! issue a MMC read mode2 sectors. - deprecated.
+  /** Read sectors using SCSI-MMC GPCMD_READ_CD. 
+      Can read only up to 25 blocks.
    */
   driver_return_code_t mmc_read_sectors ( const CdIo_t *p_cdio, void *p_buf, 
                                           lsn_t i_lsn,  int read_sector_type, 
                                           uint32_t i_blocks);
   
-  /*!
-    Run an MMC command. 
+  /**
+    Run a Multimedia command (MMC). 
     
     @param p_cdio	 CD structure set by cdio_open().
     @param i_timeout_ms  time in milliseconds we will wait for the command
@@ -756,22 +781,88 @@ mmc_audio_read_subchannel (CdIo_t *p_cdio,
 
     @return 0 if command completed successfully.
   */
-  int mmc_run_cmd( const CdIo_t *p_cdio, unsigned int i_timeout_ms,
-                   const mmc_cdb_t *p_cdb,
-                   cdio_mmc_direction_t e_direction, unsigned int i_buf, 
+  driver_return_code_t
+  mmc_run_cmd( const CdIo_t *p_cdio, unsigned int i_timeout_ms,
+               const mmc_cdb_t *p_cdb,
+               cdio_mmc_direction_t e_direction, unsigned int i_buf, 
+               /*in/out*/ void *p_buf );
+
+  /**
+    Run a Multimedia command (MMC) specifying the CDB length.
+    The motivation here is for example ot use in is an undocumented 
+    debug command for LG drives (namely E7), whose length is being 
+    miscalculated by mmc_get_cmd_len(); it doesn't follow the usual 
+    code number to length conventions. Patch supplied by SukkoPera.
+
+    @param p_cdio	 CD structure set by cdio_open().
+    @param i_timeout_ms  time in milliseconds we will wait for the command
+                         to complete. 
+    @param p_cdb	 CDB bytes. All values that are needed should be set 
+                         on input. 
+    @param i_cdb	 number of CDB bytes. 
+    @param e_direction   direction the transfer is to go.
+    @param i_buf	 Size of buffer
+    @param p_buf	 Buffer for data, both sending and receiving.
+
+    @return 0 if command completed successfully.
+  */
+  driver_return_code_t
+  mmc_run_cmd_len( const CdIo_t *p_cdio, unsigned int i_timeout_ms,
+                   const mmc_cdb_t *p_cdb, unsigned int i_cdb,
+                   cdio_mmc_direction_t e_direction, unsigned int i_buf,
                    /*in/out*/ void *p_buf );
-  /*!
+
+  /**
     Set the block size for subsequest read requests, via MMC.
   */
   driver_return_code_t mmc_set_blocksize ( const CdIo_t *p_cdio, 
                                            uint16_t i_blocksize);
   
-  /*!
-    Set the drive speed. 
+  /**
+    Set the drive speed in CD-ROM speed units.
+
+    @param p_cdio	   CD structure set by cdio_open().
+    @param i_drive_speed   speed in CD-ROM speed units. Note this
+                           not Kbs as would be used in the MMC spec or
+		           in mmc_set_speed(). To convert CD-ROM speed units 
+			   to Kbs, multiply the number by 176 (for raw data)
+			   and by 150 (for filesystem data). On many CD-ROM 
+			   drives, specifying a value too large will result 
+			   in using the fastest speed.
+
+    @return the drive speed if greater than 0. -1 if we had an error. is -2
+    returned if this is not implemented for the current driver.
+
+     @see cdio_set_speed and mmc_set_speed
   */
-  driver_return_code_t mmc_set_speed( const CdIo_t *p_cdio, int i_speed );
+  driver_return_code_t mmc_set_drive_speed( const CdIo_t *p_cdio, 
+                                            int i_drive_speed );
   
-  /*!
+  /**
+    Set the drive speed in K bytes per second.
+
+    @param p_cdio	 CD structure set by cdio_open().
+    @param i_Kbs_speed   speed in K bytes per second. Note this is 
+                         not in standard CD-ROM speed units, e.g.
+                         1x, 4x, 16x as it is in cdio_set_speed.
+                         To convert CD-ROM speed units to Kbs,
+                         multiply the number by 176 (for raw data)
+                         and by 150 (for filesystem data). 
+                         Also note that ATAPI specs say that a value
+                         less than 176 will result in an error.
+                         On many CD-ROM drives,
+                         specifying a value too large will result in using
+                         the fastest speed.
+
+    @return the drive speed if greater than 0. -1 if we had an error. is -2
+    returned if this is not implemented for the current driver.
+
+    @see cdio_set_speed and mmc_set_drive_speed
+  */
+  driver_return_code_t mmc_set_speed( const CdIo_t *p_cdio, 
+                                      int i_Kbs_speed );
+  
+  /**
     Load or Unload media using a MMC START STOP command. 
     
     @param p_cdio  the CD object to be acted upon.
@@ -801,6 +892,9 @@ extern cdio_mmc_feature_profile_t   debug_cdio_mmc_feature_profile;
 extern cdio_mmc_get_conf_t          debug_cdio_mmc_get_conf;
 extern cdio_mmc_gpcmd_t             debug_cdio_mmc_gpcmd;
 extern cdio_mmc_read_sub_state_t    debug_cdio_mmc_read_sub_state;
+extern cdio_mmc_read_cd_type_t      debug_cdio_mmc_read_cd_type;
+extern cdio_mmc_readtoc_t           debug_cdio_mmc_readtoc;
+extern cdio_mmc_mode_page_t         debug_cdio_mmc_mode_page;
   
 #endif /* __MMC_H__ */
 
