@@ -1,21 +1,20 @@
 /*
-    $Id: freebsd_cam.c,v 1.10 2005/07/23 22:24:04 rocky Exp $
+  $Id: freebsd_cam.c,v 1.12 2008/04/21 18:30:20 karl Exp $
 
-    Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2004, 2005, 2008, 2009 Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* This file contains FreeBSD-specific code and implements low-level
@@ -26,7 +25,7 @@
 # include "config.h"
 #endif
 
-static const char _rcsid[] = "$Id: freebsd_cam.c,v 1.10 2005/07/23 22:24:04 rocky Exp $";
+static const char _rcsid[] = "$Id: freebsd_cam.c,v 1.12 2008/04/21 18:30:20 karl Exp $";
 
 #ifdef HAVE_FREEBSD_CDROM
 
@@ -54,8 +53,8 @@ static const char _rcsid[] = "$Id: freebsd_cam.c,v 1.10 2005/07/23 22:24:04 rock
  */
 int
 run_mmc_cmd_freebsd_cam( const void *p_user_data, unsigned int i_timeout_ms,
-			 unsigned int i_cdb, const scsi_mmc_cdb_t *p_cdb, 
-			 scsi_mmc_direction_t e_direction, 
+			 unsigned int i_cdb, const mmc_cdb_t *p_cdb, 
+			 cdio_mmc_direction_t e_direction, 
 			 unsigned int i_buf, /*in/out*/ void *p_buf )
 {
   const _img_private_t *p_env = p_user_data;
@@ -123,6 +122,8 @@ init_freebsd_cam (_img_private_t *p_env)
       return false;
     }
 
+  (void)ioctl(p_env->gen.fd, CDIOCALLOW);
+
   if (ioctl (p_env->gen.fd, CAMGETPASSTHRU, &p_env->ccb) < 0)
     {
       cdio_warn ("open: %s", strerror (errno));
@@ -181,7 +182,7 @@ int
 read_mode2_sectors_freebsd_cam (_img_private_t *p_env, void *p_buf, 
 				lsn_t lsn, unsigned int nblocks)
 {
-  scsi_mmc_cdb_t cdb = {{0, }};
+  mmc_cdb_t cdb = {{0, }};
 
   bool b_read_10 = false;
 
@@ -229,7 +230,7 @@ driver_return_code_t
 eject_media_freebsd_cam (_img_private_t *p_env) 
 {
   int i_status;
-  scsi_mmc_cdb_t cdb = {{0, }};
+  mmc_cdb_t cdb = {{0, }};
   uint8_t buf[1];
   
   CDIO_MMC_SET_COMMAND(cdb.field, CDIO_MMC_GPCMD_ALLOW_MEDIUM_REMOVAL);
