@@ -1,7 +1,7 @@
 /*
   $Id: cdio_private.h,v 1.37 2008/04/22 15:29:11 karl Exp $
 
-  Copyright (C) 2003, 2004, 2005, 2008 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2003, 2004, 2005, 2008, 2009 Rocky Bernstein <rocky@gnu.org>
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -463,7 +463,7 @@ extern "C" {
 
   /* The below array gives of the drivers that are currently available for 
      on a particular host. */
-  extern CdIo_driver_t CdIo_driver[CDIO_MAX_DRIVER];
+  extern CdIo_driver_t CdIo_driver[];
 
   /* The last valid entry of Cdio_driver. -1 means uninitialzed. -2 
      means some sort of error.
@@ -472,7 +472,7 @@ extern "C" {
 
   /* The below array gives all drivers that can possibly appear.
      on a particular host. */
-  extern CdIo_driver_t CdIo_all_drivers[CDIO_MAX_DRIVER+1];
+  extern CdIo_driver_t CdIo_all_drivers[];
 
   /*! 
     Add/allocate a drive to the end of drives. 
@@ -485,6 +485,7 @@ extern "C" {
   driver_return_code_t close_tray_freebsd (const char *psz_drive);
   driver_return_code_t close_tray_linux   (const char *psz_drive);
   driver_return_code_t close_tray_netbsd  (const char *psz_drive);
+  driver_return_code_t close_tray_os2     (const char *psz_drive);
   driver_return_code_t close_tray_osx     (const char *psz_drive);
   driver_return_code_t close_tray_solaris (const char *psz_drive);
   driver_return_code_t close_tray_win32   (const char *psz_drive);
@@ -523,6 +524,10 @@ extern "C" {
     True if Sun Solaris driver is available. */
   bool cdio_have_solaris (void);
 
+  /*! DEPRICATED: use cdio_have_driver().
+    True if IBM OS2 driver is available. */
+  bool cdio_have_os2     (void);
+
   /*! DEPRICATED: use cdio_have_driver().
     True if Apple OSX driver is available. */
   bool cdio_have_osx     (void);
