@@ -44,11 +44,6 @@
 #include <sys/stat.h>
 #endif
 
-/* The below array gives of the drivers that are currently available for 
-   on a particular host. */
-
-CdIo_driver_t CdIo_driver[CDIO_MAX_DRIVER] = { {0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL} };
-
 /* The last valid entry of Cdio_driver. 
    -1 or (CDIO_DRIVER_UNINIT) means uninitialzed. 
    -2 means some sort of error.
@@ -67,9 +62,11 @@ const driver_id_t cdio_os_driver = DRIVER_FREEBSD;
 const driver_id_t cdio_os_driver = DRIVER_LINUX;
 #elif  HAVE_DARWIN_CDROM
 const driver_id_t cdio_os_driver = DRIVER_OSX;
-#elif  HAVE_DARWIN_SOLARIS
+#elif  HAVE_OS2_CDROM
+const driver_id_t cdio_os_driver = DRIVER_OS2;
+#elif  HAVE_SOLARIS_CDROM
 const driver_id_t cdio_os_driver = DRIVER_SOLARIS;
-#elif  HAVE_DARWIN_WIN32
+#elif  HAVE_WIN32_CDROM
 const driver_id_t cdio_os_driver = DRIVER_WIN32;
 #else 
 const driver_id_t cdio_os_driver = DRIVER_UNKNOWN;
@@ -95,7 +92,7 @@ cdio_have_false(void)
 /* The below array gives all drivers that can possibly appear.
    on a particular host. */
 
-CdIo_driver_t CdIo_all_drivers[CDIO_MAX_DRIVER+1] = {
+CdIo_driver_t CdIo_all_drivers[] = {
   {DRIVER_UNKNOWN, 
    0,
    "Unknown", 
@@ -109,7 +106,7 @@ CdIo_driver_t CdIo_all_drivers[CDIO_MAX_DRIVER+1] = {
    NULL
   },
 
-  {DRIVER_BSDI, 
+  {DRIVER_AIX, 
    CDIO_SRC_IS_DEVICE_MASK|CDIO_SRC_IS_NATIVE_MASK|CDIO_SRC_IS_SCSI_MASK,
    "AIX",
    "AIX SCSI driver",
@@ -187,6 +184,19 @@ CdIo_driver_t CdIo_all_drivers[CDIO_MAX_DRIVER+1] = {
    &close_tray_solaris
   },
 
+  {DRIVER_OS2,
+   CDIO_SRC_IS_DEVICE_MASK|CDIO_SRC_IS_NATIVE_MASK|CDIO_SRC_IS_SCSI_MASK,
+   "OS2",
+   "IBM OS/2 driver",
+   &cdio_have_os2,
+   &cdio_open_os2,
+   &cdio_open_am_os2,
+   &cdio_get_default_device_os2,
+   &cdio_is_device_os2,
+   &cdio_get_devices_os2,
+   &close_tray_os2
+  },
+
   {DRIVER_OSX, 
    CDIO_SRC_IS_DEVICE_MASK|CDIO_SRC_IS_NATIVE_MASK|CDIO_SRC_IS_SCSI_MASK,
    "OS X",
@@ -254,6 +264,41 @@ CdIo_driver_t CdIo_all_drivers[CDIO_MAX_DRIVER+1] = {
 
 };
 
+/* The below array gives of the drivers that are currently available for 
+   on a particular host. */
+
+CdIo_driver_t CdIo_driver[sizeof(CdIo_all_drivers)/sizeof(CdIo_all_drivers[0])-1] = { 
+  {0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL} };
+
+const driver_id_t cdio_drivers[] = {
+  DRIVER_AIX,
+  DRIVER_BSDI,
+  DRIVER_FREEBSD,
+  DRIVER_NETBSD,
+  DRIVER_LINUX,
+  DRIVER_SOLARIS,
+  DRIVER_OS2,
+  DRIVER_OSX,
+  DRIVER_WIN32,
+  DRIVER_CDRDAO,
+  DRIVER_BINCUE,
+  DRIVER_NRG,
+  DRIVER_UNKNOWN
+};
+
+const driver_id_t cdio_device_drivers[] = {
+  DRIVER_AIX,
+  DRIVER_BSDI,
+  DRIVER_FREEBSD,
+  DRIVER_NETBSD,
+  DRIVER_LINUX,
+  DRIVER_SOLARIS,
+  DRIVER_OS2,
+  DRIVER_OSX,
+  DRIVER_WIN32,
+  DRIVER_UNKNOWN
+};
+
 const char *
 cdio_driver_errmsg(driver_return_code_t drc)
 {
@@ -280,17 +325,17 @@ cdio_driver_errmsg(driver_return_code_t drc)
 }
 
 static CdIo *
-scan_for_driver(driver_id_t start, driver_id_t end, 
+scan_for_driver(const driver_id_t drivers[], 
                 const char *psz_source, const char *access_mode) 
 {
-  driver_id_t driver_id;
+  const driver_id_t *driver_id_p;
   
-  for (driver_id=start; driver_id<=end; driver_id++) {
-    if ((*CdIo_all_drivers[driver_id].have_driver)()) {
+  for (driver_id_p=drivers; *driver_id_p!=DRIVER_UNKNOWN; driver_id_p++) {
+    if ((*CdIo_all_drivers[*driver_id_p].have_driver)()) {
       CdIo *ret=
-        (*CdIo_all_drivers[driver_id].driver_open_am)(psz_source, access_mode);
+        (*CdIo_all_drivers[*driver_id_p].driver_open_am)(psz_source, access_mode);
       if (ret != NULL) {
-        ret->driver_id = driver_id;
+        ret->driver_id = *driver_id_p;
         return ret;
       }
     }
@@ -314,16 +359,16 @@ cdio_init(void)
   
   CdIo_driver_t *all_dp;
   CdIo_driver_t *dp = CdIo_driver;
-  driver_id_t driver_id;
+  const driver_id_t *driver_id_p;
 
   if (CdIo_last_driver != CDIO_DRIVER_UNINIT) {
     cdio_warn ("Init routine called more than once.");
     return false;
   }
 
-  for (driver_id=DRIVER_UNKNOWN+1; driver_id<=CDIO_MAX_DRIVER; driver_id++) {
-    all_dp = &CdIo_all_drivers[driver_id];
-    if ((*CdIo_all_drivers[driver_id].have_driver)()) {
+  for (driver_id_p=cdio_drivers; *driver_id_p!=DRIVER_UNKNOWN; driver_id_p++) {
+    all_dp = &CdIo_all_drivers[*driver_id_p];
+    if ((*CdIo_all_drivers[*driver_id_p].have_driver)()) {
       *dp++ = *all_dp;
       CdIo_last_driver++;
     }
@@ -372,14 +417,15 @@ cdio_close_tray (const char *psz_orig_drive, /*in/out*/ driver_id_t
     psz_drive = strdup(psz_orig_drive);
   
   if (DRIVER_UNKNOWN == *p_driver_id || DRIVER_DEVICE == *p_driver_id) {
-    *p_driver_id = CDIO_MIN_DEVICE_DRIVER;
+    const driver_id_t *driver_id_p = (DRIVER_DEVICE == *p_driver_id)?cdio_device_drivers:cdio_drivers;
     
     /* Scan for driver */
-    for ( ; *p_driver_id<=CDIO_MAX_DRIVER; (*p_driver_id)++) {
-      if ( (*CdIo_all_drivers[*p_driver_id].have_driver)() &&
-           *CdIo_all_drivers[*p_driver_id].close_tray ) {
-        drc = (*CdIo_all_drivers[*p_driver_id].close_tray)(psz_drive);
+    for ( ; *driver_id_p!=DRIVER_UNKNOWN; driver_id_p++) {
+      if ( (*CdIo_all_drivers[*driver_id_p].have_driver)() &&
+           *CdIo_all_drivers[*driver_id_p].close_tray ) {
+        drc = (*CdIo_all_drivers[*driver_id_p].close_tray)(psz_drive);
         free(psz_drive);
+        *p_driver_id = *driver_id_p;
         return drc;
       }
     }
@@ -467,12 +513,12 @@ char *
 cdio_get_default_device (const CdIo_t *p_cdio)
 {
   if (p_cdio == NULL) {
-    driver_id_t driver_id;
+    const driver_id_t *driver_id_p;
     /* Scan for driver */
-    for (driver_id=DRIVER_UNKNOWN+1; driver_id<=CDIO_MAX_DRIVER; driver_id++) {
-      if ( (*CdIo_all_drivers[driver_id].have_driver)() &&
-           *CdIo_all_drivers[driver_id].get_default_device ) {
-        return (*CdIo_all_drivers[driver_id].get_default_device)();
+    for (driver_id_p=cdio_drivers; *driver_id_p!=DRIVER_UNKNOWN; driver_id_p++) {
+      if ( (*CdIo_all_drivers[*driver_id_p].have_driver)() &&
+           *CdIo_all_drivers[*driver_id_p].get_default_device ) {
+        return (*CdIo_all_drivers[*driver_id_p].get_default_device)();
       }
     }
     return NULL;
@@ -496,16 +542,14 @@ char *
 cdio_get_default_device_driver (/*in/out*/ driver_id_t *p_driver_id)
 {
   if (DRIVER_UNKNOWN == *p_driver_id || DRIVER_DEVICE == *p_driver_id) {
-    if (DRIVER_UNKNOWN == *p_driver_id) 
-      (*p_driver_id)++;
-    else 
-      *p_driver_id = CDIO_MIN_DEVICE_DRIVER;
-    
+    const driver_id_t *driver_id_p = (DRIVER_DEVICE == *p_driver_id)?cdio_device_drivers:cdio_drivers;
+
     /* Scan for driver */
-    for ( ; *p_driver_id<=CDIO_MAX_DRIVER; (*p_driver_id)++) {
-      if ( (*CdIo_all_drivers[*p_driver_id].have_driver)() &&
-           *CdIo_all_drivers[*p_driver_id].get_default_device ) {
-        return (*CdIo_all_drivers[*p_driver_id].get_default_device)();
+    for ( ; *driver_id_p!=DRIVER_UNKNOWN; driver_id_p++) {
+      if ( (*CdIo_all_drivers[*driver_id_p].have_driver)() &&
+           *CdIo_all_drivers[*driver_id_p].get_default_device ) {
+        *p_driver_id = *driver_id_p;
+        return (*CdIo_all_drivers[*driver_id_p].get_default_device)();
       }
     }
     return NULL;
@@ -542,12 +586,11 @@ cdio_get_devices_ret (/*in/out*/ driver_id_t *p_driver_id)
   switch (*p_driver_id) {
     /* FIXME: spit out unknown to give image drivers as well.  */
   case DRIVER_DEVICE:
-    p_cdio = scan_for_driver(DRIVER_UNKNOWN+1, CDIO_MAX_DEVICE_DRIVER, 
-                             NULL, NULL);
+    p_cdio = scan_for_driver(cdio_device_drivers, NULL, NULL);
     *p_driver_id = cdio_get_driver_id(p_cdio);
     break;
   case DRIVER_UNKNOWN:
-    p_cdio = scan_for_driver(DRIVER_UNKNOWN+1, CDIO_MAX_DRIVER, NULL, NULL);
+    p_cdio = scan_for_driver(cdio_drivers, NULL, NULL);
     *p_driver_id = cdio_get_driver_id(p_cdio);
     break;
   default:
@@ -699,8 +742,7 @@ cdio_get_drive_cap_dev (const char *device,
 			cdio_drive_misc_cap_t  *p_misc_cap)
 {
   /* This seems like a safe bet. */
-  CdIo_t *cdio=scan_for_driver(CDIO_MIN_DRIVER, CDIO_MAX_DRIVER, 
-                             device, NULL);
+  CdIo_t *cdio=scan_for_driver(cdio_drivers, device, NULL);
   if (cdio) {
     cdio_get_drive_cap(cdio, p_read_cap, p_write_cap, p_misc_cap);
     cdio_destroy(cdio);
@@ -857,6 +899,9 @@ cdio_have_atapi(CdIo_t *p_cdio)
 bool
 cdio_have_driver(driver_id_t driver_id)
 {
+  if (driver_id < 0 || 
+      driver_id >= sizeof(CdIo_all_drivers)/sizeof(CdIo_all_drivers[0]))
+    return false;
   return (*CdIo_all_drivers[driver_id].have_driver)();
 }
 
@@ -864,16 +909,13 @@ bool
 cdio_is_device(const char *psz_source, driver_id_t driver_id)
 {
   if (DRIVER_UNKNOWN == driver_id || DRIVER_DEVICE == driver_id) {
-    if (DRIVER_UNKNOWN == driver_id) 
-      driver_id++;
-    else 
-      driver_id = CDIO_MIN_DEVICE_DRIVER;
+    const driver_id_t *driver_id_p = (DRIVER_DEVICE == driver_id)?cdio_device_drivers:cdio_drivers;
     
     /* Scan for driver */
-    for ( ; driver_id<=CDIO_MAX_DRIVER; driver_id++) {
-      if ( (*CdIo_all_drivers[driver_id].have_driver)() &&
-           CdIo_all_drivers[driver_id].is_device ) {
-        return (*CdIo_all_drivers[driver_id].is_device)(psz_source);
+    for ( ; *driver_id_p!=DRIVER_UNKNOWN; driver_id_p++) {
+      if ( (*CdIo_all_drivers[*driver_id_p].have_driver)() &&
+           CdIo_all_drivers[*driver_id_p].is_device ) {
+        return (*CdIo_all_drivers[*driver_id_p].is_device)(psz_source);
       }
     }
   }
@@ -918,7 +960,7 @@ cdio_open_am (const char *psz_orig_source, driver_id_t driver_id,
   switch (driver_id) {
   case DRIVER_UNKNOWN: 
     {
-      CdIo_t *p_cdio=scan_for_driver(CDIO_MIN_DRIVER, CDIO_MAX_DRIVER, 
+      CdIo_t *p_cdio=scan_for_driver(cdio_drivers,
                                      psz_source, psz_access_mode);
       free(psz_source);
       return p_cdio;
@@ -939,6 +981,7 @@ cdio_open_am (const char *psz_orig_source, driver_id_t driver_id,
   case DRIVER_SOLARIS:
   case DRIVER_WIN32:
   case DRIVER_OSX:
+  case DRIVER_OS2:
   case DRIVER_NRG:
   case DRIVER_BINCUE:
   case DRIVER_CDRDAO:
@@ -991,8 +1034,7 @@ cdio_open_am_cd (const char *psz_source, const char *psz_access_mode)
   if (CdIo_last_driver == -1) cdio_init();
 
   /* Scan for a driver. */
-  return scan_for_driver(CDIO_MIN_DEVICE_DRIVER, CDIO_MAX_DEVICE_DRIVER, 
-                         psz_source, psz_access_mode);
+  return scan_for_driver(cdio_device_drivers, psz_source, psz_access_mode);
 }
 
 /*!
