@@ -1,22 +1,20 @@
 /*
-  $Id: cd-read.c,v 1.31 2008/03/06 01:16:49 rocky Exp $
+  $Id: cd-read.c,v 1.33 2008/06/19 15:44:13 flameeyes Exp $
 
   Copyright (C) 2003, 2004, 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
   
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301 USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* Program to debug read routines audio, auto, mode1, mode2 forms 1 & 2. */
@@ -78,7 +76,7 @@ typedef struct
 
 
 /* Sub-options for --mode.  Note: entries must be sorted! */
-subopt_entry_t modes_sublist[] = {
+static const subopt_entry_t modes_sublist[] = {
   {"any",        READ_ANY},
   {"audio",      READ_AUDIO},
   {"m1f1",       READ_M1F1},
@@ -94,7 +92,7 @@ subopt_entry_t modes_sublist[] = {
 
 /* Used by `main' to communicate with `parse_opt'. And global options
  */
-struct arguments
+static struct arguments
 {
   char          *access_mode; /* Access method driver should use for control */
   char          *output_file; /* file to output blocks if not NULL. */
@@ -157,7 +155,7 @@ compare_subopts(const void *key1, const void *key2)
    flag variable to true as well as the "show.all" false. 
 */
 static void
-process_suboption(const char *subopt, subopt_entry_t *sublist, const int num,
+process_suboption(const char *subopt, const subopt_entry_t *sublist, const int num,
                   const char *subopt_name) 
 {
   subopt_entry_t *subopt_rec = 
@@ -240,7 +238,7 @@ parse_options (int argc, char *argv[])
 {
   int opt;
 
-  const char* helpText =
+  static const char helpText[] =
     "Usage: %s [OPTION...]\n"
     "  -a, --access-mode=STRING        Set CD control access mode\n"
     "  -m, --mode=MODE-TYPE            set CD-ROM read mode (audio, auto, m1f1, m1f2,\n"
@@ -273,7 +271,7 @@ parse_options (int argc, char *argv[])
     "  -?, --help                      Show this help message\n"
     "  --usage                         Display brief usage message\n";
   
-  const char* usageText =
+  static const char usageText[] =
     "Usage: %s [-a|--access-mode STRING] [-m|--mode MODE-TYPE]\n"
     "        [-d|--debug INT] [-x|--hexdump] [--no-header] [--no-hexdump]\n"
     "        [-s|--start INT] [-e|--end INT] [-n|--number INT] [-b|--bin-file FILE]\n"
@@ -282,8 +280,8 @@ parse_options (int argc, char *argv[])
     "        [-V|--version] [-?|--help] [--usage]\n";
   
   /* Command-line options */
-  const char* optionsString = "a:m:d:xjs:e:n:b::c::i::C::N::t::o:V?";
-  struct option optionsTable[] = {
+  static const char optionsString[] = "a:m:d:xjs:e:n:b::c::i::C::N::t::o:V?";
+  static const struct option optionsTable[] = {
   
     {"access-mode", required_argument, NULL, 'a'},
     {"mode", required_argument, NULL, 'm'},
