@@ -1,21 +1,20 @@
 /*
-  $Id: mmc-tool.c,v 1.10 2008/01/09 04:26:24 rocky Exp $
+  $Id: mmc-tool.c,v 1.12 2008/06/19 15:44:24 flameeyes Exp $
 
-  Copyright (C) 2006 Rocky Bernstein <rocky@cpan.org>
+  Copyright (C) 2006, 2008 Rocky Bernstein <rocky@gnu.org>
   
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* A program to using the MMC interface to list CD and drive features
@@ -79,8 +78,8 @@ typedef struct
 
 enum { MAX_OPS = 10 };
 
-unsigned int last_op = 0;
-operation_t operation[MAX_OPS] = { {OP_FINISHED, {0}} };
+static unsigned int last_op = 0;
+static operation_t operation[MAX_OPS] = { {OP_FINISHED, {0}} };
 
 static void 
 push_op(operation_t *p_op) 
@@ -99,7 +98,7 @@ parse_options (int argc, char *argv[])
   operation_t op;
   int i_blocksize = 0;
 
-  const char* helpText =
+  static const char helpText[] =
     "Usage: %s [OPTION...]\n"
     " Issues libcdio Multimedia commands. Operations occur in the order\n"
     " in which the options are given and a given operation may appear\n"
@@ -128,14 +127,14 @@ parse_options (int argc, char *argv[])
     "  -?, --help                      Show this help message\n"
     "  --usage                         Display brief usage message\n";
   
-  const char* usageText =
+  static const char usageText[] =
     "Usage: %s [-b|--blocksize[=INT]] [-m|--mcn]\n"
     "        [-I|--idle] [-I|inquiry] [-m[-s|--speed-KB INT]\n"
     "        [-V|--version] [-?|--help] [--usage]\n";
   
   /* Command-line options */
-  const char* optionsString = "b::c:C::e::Iis:V?";
-  struct option optionsTable[] = {
+  static const char optionsString[] = "b::c:C::e::Iis:V?";
+  const struct option optionsTable[] = {
   
     {"blocksize", optional_argument, &i_blocksize, 'b' },
     {"close", required_argument, NULL, 'c'},
