@@ -1,21 +1,20 @@
-/*
-  $Id: testbincue.c,v 1.5 2004/10/26 01:21:05 rocky Exp $
+/* -*- C -*-
+  $Id: testbincue.c.in,v 1.2 2008/03/22 18:08:25 karl Exp $
 
-  Copyright (C) 2004 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2004, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
   
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* 
@@ -99,6 +98,28 @@ main(int argc, const char *argv[])
       break;
     }
   }
-  
+
+  {
+    CdIo_t *p_cdio;
+    snprintf(psz_cuefile, sizeof(psz_cuefile)-1,
+	     "%s/%s", TEST_DIR, "cdda.cue");
+    p_cdio  = cdio_open (psz_cuefile, DRIVER_UNKNOWN);
+    if (!p_cdio) {
+      printf("Can't open cdda.cue\n");
+    } else {
+      /* Just test performing some operations. */
+      driver_return_code_t drc = cdio_set_blocksize(p_cdio, 2048);
+      char *psz_device = cdio_get_default_device(p_cdio);
+      /* Could chdir to srcdir to hedge the bet? */
+      if (psz_device) 
+	free(psz_device);
+      else {
+	/* Unless we do the chdir, will fail. So don't set as an  error. */
+	printf("Can't get default device\n");
+      }
+      drc = cdio_set_speed(p_cdio, 5);
+    }
+  }
+
   return ret;
 }
